@@ -1,5 +1,5 @@
-fsim.kernel.test<- function(x,y,x.test,y.test, 
-theta=theta, nknot.theta=3, order.Bspline=3, 
+fsim.kernel.test<- function(x,y,x.test,y.test=NULL, 
+theta, nknot.theta=3, order.Bspline=3, 
 h=0.5,  
 kind.of.kernel="quad", range.grid=NULL, nknot=NULL)
 {
@@ -22,7 +22,7 @@ for(j in 1:J) {
 	res.kernel.mat <- matrix(rep(res.kernel, length.curve.y), n, length.curve.y, byrow=FALSE)
 	sum.res.kernel <- sum(res.kernel)
 	if(sum.res.kernel > 0) {
-		if (length.curve.y>1)  y.hat2[j,] <- apply(y * res.kernel.mat,2,sum)/sum.res.kernel
+		if (length.curve.y>1)  y.hat2[j,] <- colSums(y * res.kernel.mat)/sum.res.kernel
 		else  y.hat2[j,] <- sum(y * res.kernel)/sum.res.kernel
 	}
 	else y.hat2[j,] <- y[order(norm.diff)[1],]
