@@ -1,11 +1,11 @@
-sfpl.kernel.fit <- function(x, z, y,
+sfpl.kernel.fit<- function(x, z, y,
 semimetric="deriv", q=NULL,
 min.q.h=0.05, max.q.h=0.5, h.seq = NULL, num.h =10,
 range.grid=NULL,  kind.of.kernel="quad", nknot=NULL, 
 lambda.min=NULL, lambda.min.h=NULL, lambda.min.l=NULL, factor.pn=1,
 nlambda=100, lambda.seq=NULL,vn=ncol(z), nfolds=10, seed=123,   
-criterion=c("GCV", "BIC", "AIC", "k-fold-CV"),  
-penalty=c("grLasso", "grMCP", "grSCAD","gel", "cMCP", "gBridge", "gLasso", "gMCP"), 
+criterion="GCV",  
+penalty="grSCAD", 
 max.iter=1000)
 {
 if (!is.matrix(z)) z <- as.matrix(z)
@@ -32,6 +32,7 @@ lambda2 <- 0
 h2 <- 0
 beta2 <- list()
 index2 <- list()
+lambdas<-list()
 IC2 <- rep(Inf, length=num.vn)
 posicion.lambda.mean.dt <- matrix(0,num.vn,2)
 h.min.opt.max.mopt <- matrix(NA,num.vn,3)
@@ -54,8 +55,8 @@ for (v in 1:num.vn) {
 	IC.s <- 0
 	if (criterion != "k-fold-CV") {
 		for (s in 1:num.h) {
-			if (is.null(lambda.seq)) aux0 <-  try(grpreg(X=as.matrix(XX[,,s]), y=yy[,s], group=group, lambda.min=lambda.min, nlambda=nlambda, penalty=penalty, max.iter=max.iter), silent=FALSE)
-			else aux0 <-  try(grpreg(X=as.matrix(XX[,,s]), y=yy[,s], group=group, lambda=lambda.seq, penalty=penalty, max.iter=max.iter), silent=FALSE)
+			if (is.null(lambda.seq)) aux0 <-  try(grpreg(X=as.matrix(XX[,,s]), y=yy[,s], group=group, lambda.min=lambda.min, nlambda=nlambda, penalty=penalty, max.iter=max.iter), silent=TRUE)
+			else aux0 <-  try(grpreg(X=as.matrix(XX[,,s]), y=yy[,s], group=group, lambda=lambda.seq, penalty=penalty, max.iter=max.iter), silent=TRUE)
 			if (inherits(aux0,"try-error")) {
 				lambda.s[s] <- NaN
 				IC.s[s] <- NaN
@@ -71,9 +72,10 @@ for (v in 1:num.vn) {
 		}
 		s.opt <- order(IC.s)[1]
 		lambda2[v] <- lambda.s[s.opt]
+		lambdas[[v]]<-lambda.s
 		h2[v] <- h.seq[s.opt]
 		IC2[v] <- IC.s[s.opt]
-		aux <- try(grpreg(X=as.matrix(XX[,,s.opt]), y=yy[,s.opt], group=group, lambda=lambda2[v], penalty=penalty, max.iter=max.iter), silent=FALSE)
+		aux <- try(grpreg(X=as.matrix(XX[,,s.opt]), y=yy[,s.opt], group=group, lambda=lambda2[v], penalty=penalty, max.iter=max.iter), silent=TRUE)
 		if (inherits(aux,"try-error")) next
 		beta2[[v]] <- aux$beta[-1]
 		index2[[v]] <- indexes.beta[beta2[[v]]!=0]
@@ -82,8 +84,8 @@ for (v in 1:num.vn) {
 		ss <- 0
 		for (s in 1:num.h) {  
 			if (is.null(lambda.seq)) aux <-  try(cv.grpreg(lambda.min=lambda.min, nlambda=nlambda, X=as.matrix(XX[,,s]), y=yy[,s], group=group, penalty=penalty, 
-														   nfolds=nfolds, max.iter=max.iter, seed=seed), silent=FALSE)
-			else aux <-  try(cv.grpreg(lambda=lambda.seq, X=as.matrix(XX[,,s]), y=yy[,s], group=group, penalty=penalty, nfolds=nfolds, max.iter=max.iter, seed=seed), silent=FALSE)
+														   nfolds=nfolds, max.iter=max.iter, seed=seed), silent=TRUE)
+			else aux <-  try(cv.grpreg(lambda=lambda.seq, X=as.matrix(XX[,,s]), y=yy[,s], group=group, penalty=penalty, nfolds=nfolds, max.iter=max.iter, seed=seed), silent=TRUE)
 			if (inherits(aux,"try-error")) {
 				lambda.s[s] <- NaN
 				IC.s[s] <- NaN
@@ -104,7 +106,7 @@ for (v in 1:num.vn) {
 		lambda2[v] <- lambda.s[s.opt]
 		h2[v] <- h.seq[s.opt]
 		IC2[v] <- IC.s[s.opt]
-		aux <- try(grpreg(X=as.matrix(XX[,,s.opt]), y=yy[,s.opt], group=group, lambda=lambda2[v], penalty=penalty, max.iter=max.iter), silent=FALSE)
+		aux <- try(grpreg(X=as.matrix(XX[,,s.opt]), y=yy[,s.opt], group=group, lambda=lambda2[v], penalty=penalty, max.iter=max.iter), silent=TRUE)
 		if (inherits(aux,"try-error")) next
 		beta2[[v]] <- aux$beta[-1]
 		index2[[v]] <- indexes.beta[beta2[[v]]!=0]
@@ -119,7 +121,7 @@ res<-y-yhp
 call<-match.call()
 out<-list(fitted.values=yhp,residuals=res,beta.est=beta2[[ind.vn]],indexes.beta.nonnull=index2[[ind.vn]], h.opt=h2[ind.vn],
 		  lambda.opt=lambda2[ind.vn], IC=IC2[ind.vn], h.min.opt.max.mopt=h.min.opt.max.mopt[ind.vn,],  
-		  posicion.lambda.mean.dt=posicion.lambda.mean.dt,vn.opt=vn.opt,
+		  vn.opt=vn.opt,lambda.opt.h=lambdas,
 		  call=call,y=y,x=x,z=z, n=n, 
 		  kind.of.kernel=kind.of.kernel,range.grid=range.grid,nknot=nknot,max.iter=max.iter,
 		  semimetric=semimetric,q=q, 
